@@ -253,8 +253,19 @@
 			if (window.outerHeight > 768) {
 				$message.blur().focus();
 			}
+			$message.on('keydown', function() {
+				// Track scroll position to be able to properly update it after
+				// the new message field shrinks as a result of pressing the
+				// delete or backspace keys.
+				this._scrollPositionOnLastKeyDown = this.$container.scrollTop();
+			}.bind(this));
 			$message.on('keydown input change', _.bind(this._onTypeComment, this));
 
+			// Before the 3.0.0 release jQuery rounded the height to the nearest
+			// integer, but Firefox has subpixel accuracy, so the height
+			// returned by jQuery can not be used in the calculations.
+			this._newMessageFieldHeight = $message.get(0).getBoundingClientRect().height;
+
 			/**
 			 * Make sure we focus the actual content part not the placeholder.
 			 * Firefox is a bit buggy there: https://stackoverflow.com/a/42170494
@@ -384,6 +395,31 @@
 			this._virtualList.reload();
 		},
 
+		/**
+		 * Scrolls the message list to keep the last visible message at the
+		 * bottom when the new message field height changes.
+		 *
+		 * @param {number} heightDifference The difference between the current
+		 *                 height of the new message field and the previous one.
+		 */
+		onNewMessageFieldHeightChange: function(heightDifference) {
+			if (heightDifference < 0) {
+				// When the new message field shrunks the message list may be
+				// automatically scrolled to fill the now empty space. For
+				// example, if the message list has 30px hidden at the bottom
+				// and the new message field shrunks 45px the message list is
+				// scrolled back 15px to align the bottom of its contents with
+				// the bottom of its new visible area. In that case the
+				// full height difference should not be scrolled back, only the
+				// part that has not been automatically scrolled yet.
+				heightDifference += this._scrollPositionOnLastKeyDown - this.$container.scrollTop();
+			}
+
+			this.$container.scrollTop(this.$container.scrollTop() + heightDifference);
+
+			this.reloadMessageList();
+		},
+
 		_formatItem: function(commentModel) {
 			// PHP timestamp is second-based; JavaScript timestamp is
 			// millisecond based.
@@ -399,7 +435,7 @@
 			}
 
 			var formattedMessage = escapeHTML(commentModel.get('message'));
-			formattedMessage = OCP.Comments.plainToRich(formattedMessage);
+			formattedMessage = this._plainToRich(formattedMessage);
 			formattedMessage = formattedMessage.replace(/\n/g, '<br/>');
 			formattedMessage = OCA.SpreedMe.Views.RichObjectStringParser.parseMessage(
 				formattedMessage, commentModel.get('messageParameters'));
@@ -415,6 +451,32 @@
 			return data;
 		},
 
+		_plainToRich: function(message) {
+			/**
+			 * In Talk we only parse URLs with a protocol to avoid undesired
+			 * clickables like composer.json. Therefor the method and regex were
+			 * copied from OCP.Comments and adjusted accordingly.
+			 */
+			// var urlRegex = /(\s|^)(https?:\/\/)?((?:[-A-Z0-9+_]+\.)+[-A-Z]+(?:\/[-A-Z0-9+&@#%?=~_|!:,.;()]*)*)(\s|$)/ig;
+			var urlRegex = /(\s|\(|^)(https?:\/\/)((?:[-A-Z0-9+_]+\.)+[-A-Z]+(?:\/[-A-Z0-9+&@#%?=~_|!:,.;()]*)*)(?=\s|\)|$)/ig;
+			return message.replace(urlRegex, function (_, leadingSpace, protocol, url) {
+				var trailingClosingBracket = '';
+				if (url.substr(-1) === ')' && (url.indexOf('(') === -1 || leadingSpace === '(')) {
+					url = url.substr(0, url.length - 1);
+					trailingClosingBracket = ')';
+				}
+				var linkText = url;
+				// if (!protocol) {
+				// 	protocol = 'https://';
+				// } else
+				if (protocol === 'http://') {
+					linkText = protocol + url;
+				}
+
+				return leadingSpace + '<a class="external" target="_blank" rel="noopener noreferrer" href="' + protocol + url + '">' + linkText + '</a>' + trailingClosingBracket;
+			});
+		},
+
 		_onAddModelStart: function() {
 			this._virtualList.appendElementStart();
 
@@ -668,6 +730,15 @@
 				$field.data('submitButtonEl', $submitButton);
 			}
 
+			var newMessageFieldOldHeight = this._newMessageFieldHeight;
+			// Before the 3.0.0 release jQuery rounded the height to the nearest
+			// integer, but Firefox has subpixel accuracy, so the height
+			// returned by jQuery can not be used in the calculations.
+			this._newMessageFieldHeight = $field.get(0).getBoundingClientRect().height;
+			if (this._newMessageFieldHeight !== newMessageFieldOldHeight) {
+				this.triggerMethod('newMessageFieldHeightChange', this._newMessageFieldHeight - newMessageFieldOldHeight);
+			}
+
 			// Submits form with Enter, but Shift+Enter is a new line. If the
 			// autocomplete popover is being shown Enter does not submit the
 			// form either; it will be handled by At.js which will add the
