@@ -137,6 +137,12 @@ OC.L10N.register(
     "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Du bjöds in för ett <strong>pratrum</strong> eller hade ett <strong>samtal</strong>",
     "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Välkommen till Nextcloud Talk!\nI denna konversation kommer du att bli informerad om nya funktioner som finns i Nextcloud Talk.",
     "New in Talk 6" : "Nytt i Talk 6",
+    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge och Safari kan nu användas för att delta i ljud- och videosamtal",
+    "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- En-till-en-konversationer är nu beständiga och kan inte längre omvandlas till gruppsamtal av misstag. När en av deltagarna lämnar samtalet raderas konversationen inte längre automatiskt. Endast om båda deltagarna lämnar samtalet raderas konversationen från servern.",
+    "- You can now notify all participants by posting \"@all\" into the chat" : "- Du kan nu meddela alla deltagare genom att skicka \"@all\" till chatten",
+    "- With the \"arrow-up\" key you can repost your last message" : "- Med \"pil upp\" -knappen kan du skicka om ditt senaste meddelande",
+    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk kan nu ha kommandon, skicka \"/help\" som ett chattmeddelande för att se om din administratör har konfigurerat några",
+    "- With projects you can create quick links between conversations, files and other items" : "- Med projekt kan du skapa snabba länkar mellan konversationer, filer och andra objekt",
     "There are currently no commands available." : "Det finns för närvarande inga kommandon tillgängliga.",
     "The command does not exist" : "Kommandot finns inte",
     "Talk updates ✅" : "Talk uppdateringar ✅",
